# JaxILI

This is a package to run Neural Density Estimation using Jax.

**Work is still in progress**

## Installation

To install the package, clone the repository and create a conda environment using `conda_env.yml`.

```bash
git clone https://github.com/sachaguer/jaxili.git
cd jaxili
conda env create -f conda_env.yml
```

You can then use pip to install the library in your conda environment.

```bash
conda activate jaxili
pip install .
```